@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -37,25 +37,50 @@
 #include "af_vfs.h"
 #include "compression.h"
 
+typedef int bool;
+#define AF_TRUE (1)
+#define AF_FALSE (0)
+
+typedef int status;
+#define AF_SUCCEED (0)
+#define AF_FAIL (-1)
+
+typedef union AFPVu
+{
+	long	l;
+	double	d;
+	void	*v;
+} AFPVu;
+
+typedef struct _InstParamInfo
+{
+	int	id;
+	int	type;
+	char	*name;
+	AFPVu	defaultValue;
+} _InstParamInfo;
+
 struct _AFfilesetup
 {
-	int		fileFormat;
-	int		channelCount;
-	int		sampleWidth, sampleFormat;
-	int		byteOrder;
+	int	valid;
+
+	int	fileFormat;
+	int	channelCount;
+	int	sampleWidth, sampleFormat;
+	int	byteOrder;
 	double	sampleRate;
 
-	int					loopCount;
+	int			loopCount;
 	struct _Loop		*loops;
-	int					markerCount;
+	int			markerCount;
 	struct _Marker		*markers;
-	int					instrumentCount;
+	int			instrumentCount;
 	struct _Instrument	*instruments;
 
-	int						miscellaneousCount;
+	int			miscellaneousCount;
 	struct _Miscellaneous	*miscellaneous;
 
-	int		aesDataPresent;
+	bool	aesDataPresent;
 	char	aesData[24];
 
 	struct _Compression	*compression;
@@ -112,6 +137,8 @@ struct _Miscellaneous
 
 struct _AFfilehandle
 {
+	int	valid;
+
         AF_VirtualFile *fh;
 
 	int 	channelCount;
@@ -148,6 +175,12 @@ enum
 	AIFC_VERSION_1 = 0xa2805140
 };
 
+enum
+{
+	_AF_VALID_FILESETUP = 38211,
+	_AF_VALID_FILEHANDLE = 38212
+};
+
 #include "error.h"
 
 #endif
