@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998-1999, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -40,17 +40,16 @@
 #include "afinternal.h"
 #include "afinternal.h"
 #include "block.h"
+#include "unit.h"
 
-int _af_parseaiff (AFfilehandle filehandle);
-int _af_parsewave (AFfilehandle filehandle);
-int _af_parseau (AFfilehandle filehandle);
-
-int aiffSyncFile (AFfilehandle);
-int waveSyncFile (AFfilehandle);
-int auSyncFile (AFfilehandle);
+status _af_aiff_update (AFfilehandle);
+status _af_wave_update (AFfilehandle);
+status _af_next_update (AFfilehandle);
 
 void aiffOpenFileWrite (AFfilehandle);
 
+extern _Unit _af_units[];
+
 int afSetVirtualByteOrder (AFfilehandle file, int track, int byteorder)
 {
 	assert(file);
@@ -60,20 +59,20 @@ int afSetVirtualByteOrder (AFfilehandle file, int track, int byteorder)
 
 	if (file == NULL)
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 
 	if (track != AF_DEFAULT_TRACK)
 	{
-		_af_error(AF_BAD_TRACKID);
+		_af_error(AF_BAD_TRACKID, "bad track ID");
 		return -1;
 	}
 
 	if (byteorder != AF_BYTEORDER_BIGENDIAN &&
 		byteorder != AF_BYTEORDER_LITTLEENDIAN)
 	{
-		_af_error(AF_BAD_BYTEORDER);
+		_af_error(AF_BAD_BYTEORDER, "bad byte order");
 		return -1;
 	}
 
@@ -148,7 +147,7 @@ int afGetChannels(AFfilehandle file, int track)
 
 	if (file == NULL)
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 
@@ -204,7 +203,7 @@ AFframecount afGetFrameCount (AFfilehandle file, int track)
 	}
 	else
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 }
@@ -225,25 +224,25 @@ int afSyncFile (AFfilehandle file)
 	*/
 	if (file == NULL)
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 
 	if (file->fileFormat == AF_FILE_AIFFC)
-		return aiffSyncFile(file);
+		return _af_aiff_update(file);
 	else if (file->fileFormat == AF_FILE_AIFF)
-		return aiffSyncFile(file);
+		return _af_aiff_update(file);
 	else if (file->fileFormat == AF_FILE_WAVE)
-		return waveSyncFile(file);
+		return _af_wave_update(file);
 	else if (file->fileFormat == AF_FILE_NEXTSND)
-		return auSyncFile(file);
+		return _af_next_update(file);
 	/*
 		If none of the above branches are taken, the filehandle must be
 		invalid.
 	*/
 	else
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 }
@@ -258,7 +257,7 @@ int afCloseFile (AFfilehandle file)
 	/* It is an error to close a null file. */
 	if (file == NULL)
 	{
-		_af_error(AF_BAD_FILEHANDLE);
+		_af_error(AF_BAD_FILEHANDLE, "bad file handle");
 		return -1;
 	}
 
@@ -307,7 +306,7 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 {
 	AFfilehandle	filehandle;
 
-	filehandle = malloc(sizeof (struct _AFfilehandle));
+	filehandle = _af_malloc(sizeof (struct _AFfilehandle));
 	if (filehandle == NULL)
 		return NULL;
 
@@ -349,7 +348,7 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 	else
 	{
 		filehandle->miscellaneousCount = setup->miscellaneousCount;
-		filehandle->miscellaneous = malloc(filehandle->miscellaneousCount *
+		filehandle->miscellaneous = _af_malloc(filehandle->miscellaneousCount *
 			sizeof (struct _Miscellaneous));
 		memcpy(filehandle->miscellaneous, setup->miscellaneous,
 			filehandle->miscellaneousCount * sizeof (struct _Miscellaneous));
@@ -364,7 +363,7 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 		filehandle->sampleFormat = AF_SAMPFMT_TWOSCOMP;
 
 		filehandle->markerCount = 4;
-		filehandle->markers = malloc(4 * sizeof (struct _Marker));
+		filehandle->markers = _af_malloc(4 * sizeof (struct _Marker));
 		memcpy(filehandle->markers, setup->markers,
 			4 * sizeof (struct _Marker));
 
@@ -374,13 +373,13 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 		}
 
 		filehandle->loopCount = 2;
-		filehandle->loops = malloc(2 * sizeof (struct _Loop));
+		filehandle->loops = _af_malloc(2 * sizeof (struct _Loop));
 		assert(filehandle->loops);
 		assert(setup->loops);
 		memcpy(filehandle->loops, setup->loops, 2 * sizeof (struct _Loop));
 
 		filehandle->instrumentCount = 1;
-		filehandle->instruments = malloc(2 * sizeof (struct _Instrument));
+		filehandle->instruments = _af_malloc(2 * sizeof (struct _Instrument));
 		assert(filehandle->instruments);
 		assert(setup->instruments);
 		memcpy(filehandle->instruments, setup->instruments,
@@ -398,6 +397,7 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 	}
 
 #ifdef DEBUG
+	printf("**_afOpenFileWrite2**\n");
 	_af_printfilehandle(filehandle);
 #endif
 
@@ -407,20 +407,13 @@ static AFfilehandle _afOpenFileWrite2 (AFvirtualfile *vf, AFfilesetup setup)
 AFfilehandle afOpenVirtualFile (AFvirtualfile *vfile, const char *mode, AFfilesetup setup)
 {
 	AFfilehandle	filehandle;
-	char			data[12];
+	int		i;
 
 	if (!strcmp(mode, "w"))
 		return _afOpenFileWrite2 (vfile, setup);
 
-	filehandle = malloc(sizeof (struct _AFfilehandle));
-	if (filehandle == NULL)
-	{
-		_af_error(AF_BAD_NO_FILEHANDLE);
-		return NULL;
-	}
-
-	af_fread(data, 1, 12, vfile);
-	af_fseek(vfile, 0, SEEK_SET);
+	filehandle = _af_malloc(sizeof (struct _AFfilehandle));
+	assert(filehandle);
 
 	filehandle->fh = vfile;
 	filehandle->currentFrame = 0;
@@ -432,7 +425,7 @@ AFfilehandle afOpenVirtualFile (AFvirtualfile *vfile, const char *mode, AFfilese
 	filehandle->instruments = NULL;
 	filehandle->miscellaneousCount = 0;
 	filehandle->miscellaneous = NULL;
-	filehandle->aesDataPresent = 0;
+	filehandle->aesDataPresent = AF_FALSE;
 	filehandle->compression = NULL;
 
 #if WORDS_BIGENDIAN
@@ -441,70 +434,44 @@ AFfilehandle afOpenVirtualFile (AFvirtualfile *vfile, const char *mode, AFfilese
 	filehandle->virtualByteOrder = AF_BYTEORDER_LITTLEENDIAN;
 #endif
 
-	if (!memcmp(data, "FORM", 4) && !memcmp(data + 8, "AIFC", 4))
+	for (i=0; i<_AF_NUM_UNITS; i++)
 	{
+		if (_af_units[i].read.recognize(vfile))
+		{
+			status	result;
 #ifdef DEBUG
-		printf("detected aifc file\n");
+			printf("detected %s file\n", _af_units[i].label);
 #endif
+			filehandle->fileFormat = _af_units[i].fileFormat;
+			filehandle->sampleFormat = _af_units[i].defaultSampleFormat;
+			result = _af_units[i].read.init(setup, filehandle);
 
-		filehandle->fileFormat = AF_FILE_AIFFC;
-		filehandle->sampleFormat = AF_SAMPFMT_TWOSCOMP;
-		filehandle->byteOrder = AF_BYTEORDER_BIGENDIAN;
+			if (result == AF_FAIL)
+			{
+				/*
+					The only memory allocated is that
+					from the initial malloc.
 
-		_af_parseaiff(filehandle);
-	}
-	else if (!memcmp(data, "FORM", 4) && !memcmp(data + 8, "AIFF", 4))
-	{
-#ifdef DEBUG
-		printf("detected aiff file\n");
-#endif
+					None of the structures referenced
+					within the file handle structure
+					have had memory allocated if
+					none of the parsers recognized
+					the file.
+				*/
 
-		filehandle->fileFormat = AF_FILE_AIFF;
-		filehandle->sampleFormat = AF_SAMPFMT_TWOSCOMP;
-		filehandle->byteOrder = AF_BYTEORDER_BIGENDIAN;
+				free(filehandle);
+				return AF_NULL_FILEHANDLE;
+			}
 
-		_af_parseaiff(filehandle);
-	}
-	else if (!memcmp(data, "RIFF", 4) && !memcmp(data + 8, "WAVE", 4))
-	{
-#ifdef DEBUG
-		printf("detected wave file\n");
-#endif
-
-		filehandle->fileFormat = AF_FILE_WAVE;
-		filehandle->sampleFormat = AF_SAMPFMT_TWOSCOMP;
-		filehandle->byteOrder = AF_BYTEORDER_LITTLEENDIAN;
-
-		_af_parsewave(filehandle);
-	}
-	else if (!memcmp(data, ".snd", 4))
-	{
-#ifdef DEBUG
-		printf("detected next/sun sound file\n");
-#endif
-
-		filehandle->fileFormat = AF_FILE_NEXTSND;
-		filehandle->byteOrder = AF_BYTEORDER_BIGENDIAN;
-
-		_af_parseau(filehandle);
-	}
-	else
-	{
-		/*
-			The only memory allocated is that from the initial malloc.
-			None of the structures referenced within the file handle
-			structure have had memory allocated if none of the parsers
-			recognized the file.
-		*/
-
-		free(filehandle);
-		return AF_NULL_FILEHANDLE;
+			break;
+		}
 	}
 
 	filehandle->virtualSampleFormat = filehandle->sampleFormat;
 	filehandle->virtualSampleWidth = filehandle->sampleWidth;
 
 #ifdef DEBUG
+	printf("**afOpenVirtualFile**\n");
 	_af_printfilehandle(filehandle);
 #endif
 
@@ -518,7 +485,7 @@ AFfilehandle afOpenFile (const char *filename, const char *mode, AFfilesetup set
 	fp = fopen(filename, mode);
 	if (fp == NULL)
 	{
-		_af_error(AF_BAD_OPEN);
+		_af_error(AF_BAD_OPEN, "open failed");
 		return AF_NULL_FILEHANDLE;
 	}
 
@@ -532,7 +499,7 @@ AFfilehandle afOpenFD (int fd, const char *mode, AFfilesetup setup)
 	fp = fdopen(fd, mode);
 	if (fp == NULL)
 	{
-		_af_error(AF_BAD_OPEN);
+		_af_error(AF_BAD_OPEN, "open failed");
 		return AF_NULL_FILEHANDLE;
 	}
 
@@ -623,7 +590,7 @@ AFframecount afSeekFrame (AFfilehandle file, int track, AFframecount frame)
 
 	if (af_fseek(file->fh, file->dataStart + frameSize * frame, SEEK_SET) != 0)
 	{
-		_af_error(AF_BAD_LSEEK);
+		_af_error(AF_BAD_LSEEK, "bad seek");
 		return -1;
 	}
 
