@@ -1,22 +1,21 @@
 /*
 	Audio File Library
-
-	Copyright 1998, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
-	modify it under the terms of the GNU General Public License as
-	published by the Free Software Foundation; either version 2 of
-	the License, or (at your option) any later version.
+	modify it under the terms of the GNU Library General Public
+	License as published by the Free Software Foundation; either
+	version 2 of the License, or (at your option) any later version.
 
-	This library is distributed in the hope that it will be
-	useful, but WITHOUT ANY WARRANTY; without even the implied
-	warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-	PURPOSE.  See the GNU General Public License for more details.
+	This library is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+	Library General Public License for more details.
 
-	You should have received a copy of the GNU General Public
-	License along with this program; if not, write to the Free
-	Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-	MA 02111-1307, USA.
+	You should have received a copy of the GNU Library General Public
+	License along with this library; if not, write to the 
+	Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
+	Boston, MA  02111-1307  USA.
 */
 
 /*
@@ -28,9 +27,21 @@
 #ifndef AUDIOFILE_H
 #define AUDIOFILE_H
 
+/*
+	AFvirtualfile is the preferred type to use; AF_VirtualFile will go
+	away.
+*/
+typedef struct _AF_VirtualFile AFvirtualfile;
+typedef struct _AF_VirtualFile AF_VirtualFile;
+
 #include <sys/types.h>
 #include "aupvlist.h"
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif /* __cplusplus */
+
 typedef struct _AFfilesetup *AFfilesetup;
 typedef struct _AFfilehandle *AFfilehandle;
 typedef void (*AFerrfunc)(long, const char *);
@@ -71,21 +82,9 @@ enum
 	AF_FILE_AIFFC = 1,
 	AF_FILE_AIFF = 2,
 	AF_FILE_NEXTSND = 3,
-	AF_FILE_WAVE = 4,
-	AF_FILE_BICSF = 5,
-	AF_FILE_MPEG1BITSTREAM = 6,
-	AF_FILE_SOUNDDESIGNER1 = 7,
-	AF_FILE_SOUNDDESIGNER2 = 8,
-	AF_FILE_AVR = 9,
-	AF_FILE_IFF_8SVX = 10,
-	AF_FILE_SAMPLEVISION = 11,
-	AF_FILE_VOC = 12,
-	AF_FILE_NIST_SPHERE = 13,
-	AF_FILE_SOUNDFONT2 = 14,
+	AF_FILE_WAVE = 4
 };
 
-#define AF_FILE_IRCAM AF_FILE_BICSF
-
 enum
 {
 	AF_LOOP_MODE_NOLOOP = 0,
@@ -95,17 +94,17 @@ enum
 
 enum
 {
-	AF_SAMPFMT_TWOSCOMP = 401,
-	AF_SAMPFMT_UNSIGNED = 402,
-	AF_SAMPFMT_FLOAT = 403,
-	AF_SAMPFMT_DOUBLE = 404
+	AF_SAMPFMT_TWOSCOMP = 401, /* linear two's complement */
+	AF_SAMPFMT_UNSIGNED = 402, /* unsigned integer */
+	AF_SAMPFMT_FLOAT = 403, /* 32-bit IEEE floating-point */
+	AF_SAMPFMT_DOUBLE = 404 /* 64-bit IEEE double-precision floating-point */
 };
 
 enum
 {
 	AF_INST_LOOP_OFF = 0,			/* no looping */
 	AF_INST_LOOP_CONTINUOUS = 1,	/* loop continuously through decay */
-	AF_INST_LOOP_SUSTAIN = 3,		/* loop during sustain, then continue */
+	AF_INST_LOOP_SUSTAIN = 3		/* loop during sustain, then continue */
 };
 
 enum
@@ -151,32 +150,24 @@ enum
 
 enum
 {
+	/* supported compression schemes */
 	AF_COMPRESSION_UNKNOWN = -1,
 	AF_COMPRESSION_NONE = 0,
 	AF_COMPRESSION_G722 = 501,
 	AF_COMPRESSION_G711_ULAW = 502,
 	AF_COMPRESSION_G711_ALAW = 503,
 
+	/* Apple proprietary AIFF-C compression schemes (not supported) */
 	AF_COMPRESSION_APPLE_ACE2 = 504,
 	AF_COMPRESSION_APPLE_ACE8 = 505,
 	AF_COMPRESSION_APPLE_MAC3 = 506,
 	AF_COMPRESSION_APPLE_MAC6 = 507,
 
-	AF_COMPRESSION_MPEG1 = 515,
-	AF_COMPRESSION_AWARE_MULTIRATE = 516,
-
 	AF_COMPRESSION_G726 = 517,
 	AF_COMPRESSION_G728 = 518,
 	AF_COMPRESSION_DVI_AUDIO = 519,
 	AF_COMPRESSION_GSM = 520,
-	AF_COMPRESSION_FS1016 = 521,
-
-	AF_COMPRESSION_DEFAULT_MPEG_I = 508,
-	AF_COMPRESSION_DEFAULT_MPEG1_LAYERI = AF_COMPRESSION_DEFAULT_MPEG_I,
-	AF_COMPRESSION_DEFAULT_MPEG_II = 509,
-	AF_COMPRESSION_DEFAULT_MPEG1_LAYERII = AF_COMPRESSION_DEFAULT_MPEG_II,
-	AF_COMPRESSION_DEFAULT_MULTIRATE = 513,
-	AF_COMPRESSION_DEFAULT_LOSSLESS = 514
+	AF_COMPRESSION_FS1016 = 521
 };
 
 /* tokens for afQuery() -- see the man page for instructions */
@@ -406,6 +397,7 @@ int afIdentifyNamedFD (int, const char *filename, int *implemented);
 
 AFfilehandle afOpenFile (const char *filename, const char *mode,
 	AFfilesetup setup);
+AFfilehandle afOpenVirtualFile(AF_VirtualFile *vfile, const char *mode, AFfilesetup setup);
 AFfilehandle afOpenFD (int fd, const char *mode, AFfilesetup setup);
 AFfilehandle afOpenNamedFD (int fd, const char *mode, AFfilesetup setup,
 	const char *filename);
@@ -470,16 +462,16 @@ int afGetVirtualChannels (AFfilehandle, int track);
 void afSetChannelMatrix (AFfilehandle, int track, double *matrix);
 
 /* track data: sample format and sample width */
+void afInitSampleFormat (AFfilesetup, int track, int sampleFormat,
+	int sampleWidth);
 void afGetSampleFormat (AFfilehandle file, int track, int *sampfmt,
 	int *sampwidth);
 void afGetVirtualSampleFormat (AFfilehandle file, int track, int *sampfmt,
 	int *sampwidth);
-#if 0
 int afSetVirtualSampleFormat (AFfilehandle, int track,
 	int sampleFormat, int sampleWidth);
 void afGetVirtualSampleFormat (AFfilehandle, int track,
 	int *sampleFormat, int *sampleWidth);
-#endif
 
 /* track data: sampling rate */
 void afInitRate (AFfilesetup, int track, double rate);
@@ -490,13 +482,15 @@ int afSetVirtualRate (AFfilehandle, int track, double rate);
 double afGetVirtualRate (AFfilehandle, int track);
 #endif
 
-#if 0
 /* track data: compression */
 void afInitCompression (AFfilesetup, int track, int compression);
+#if 0
 void afInitCompressionParams (AFfilesetup, int track, int compression
 	AUpvlist params, int parameterCount);
+#endif
 
 int afGetCompression (AFfilehandle, int track);
+#if 0
 void afGetCompressionParams (AFfilehandle, int track, int *compression,
 	AUpvlist params, int parameterCount);
 
@@ -592,4 +586,8 @@ int afWriteMisc (AFfilehandle, int miscellaneousid, void *buf, int bytes);
 int afReadMisc (AFfilehandle, int miscellaneousid, void *buf, int bytes);
 int afSeekMisc (AFfilehandle, int miscellaneousid, int offset);
 
-#endif
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+#endif /* AUDIOFILE_H */
