@@ -58,7 +58,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 	if (af_fseek(file->fh, file->dataStart + file->currentFrame * frameSize,
 		SEEK_SET) != 0)
 	{
-		_af_error(AF_BAD_LSEEK);
+		_af_error(AF_BAD_LSEEK, "bad seek");
 		return 0;
 	}
 
@@ -83,7 +83,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 					datum = *buffer8++;
 					if (af_fwrite(&datum, 1, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -98,7 +98,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 					datum ^= 128;
 					if (af_fwrite(&datum, 1, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -106,7 +106,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 				break;
 
 			default:
-				_af_error(AF_BAD_SAMPFMT);
+				_af_error(AF_BAD_SAMPFMT, "bad sample format");
 				break;
 		}
 	}
@@ -124,7 +124,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 						datum = _af_byteswapint16(datum);
 					if (af_fwrite(&datum, 2, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -140,7 +140,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 					datum ^= 0x8000;
 					if (af_fwrite(&datum, 2, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -148,7 +148,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 				break;
 
 			default:
-				_af_error(AF_BAD_SAMPFMT);
+				_af_error(AF_BAD_SAMPFMT, "bad sample format");
 				break;
 		}
 	}
@@ -177,7 +177,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 
 					if (af_fwrite(threeBytes, 3, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 
@@ -186,7 +186,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 				break;
 
 			default:
-				_af_error(AF_BAD_SAMPFMT);
+				_af_error(AF_BAD_SAMPFMT, "bad sample format");
 				break;
 		}
 	}
@@ -204,7 +204,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 						datum = _af_byteswapint32(datum);
 					if (af_fwrite(&datum, 4, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -221,7 +221,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 					datum ^= 0x80000000;
 					if (af_fwrite(&datum, 4, 1, file->fh) < 1)
 					{
-						_af_error(AF_BAD_WRITE);
+						_af_error(AF_BAD_WRITE, "bad write");
 						break;
 					}
 					done++;
@@ -229,7 +229,7 @@ int _af_blockWriteFrames (AFfilehandle file, int track, void *samples,
 				break;
 
 			default:
-				_af_error(AF_BAD_SAMPFMT);
+				_af_error(AF_BAD_SAMPFMT, "bad sample format");
 				break;
 		}
 	}
