@@ -64,7 +64,7 @@ void afInitCompression (AFfilesetup setup, int trackid, int compression)
 
 	setup->compression = findCompression(compression);
 	if (setup->compression == NULL)
-		_af_error(AF_BAD_CODEC_TYPE);
+		_af_error(AF_BAD_CODEC_TYPE, "bad codec type");
 }
 
 #if 0
