@@ -37,7 +37,7 @@ AFerrfunc errorFunction = defaultErrorFunction;
 AFerrfunc afSetErrorHandler (AFerrfunc efunc)
 {
 	AFerrfunc	old;
-
+	
 	old = errorFunction;
 	errorFunction = efunc;
 
@@ -51,10 +51,19 @@ static void defaultErrorFunction (long error, const char *str)
 	fprintf(stderr, "\n");
 }
 
-void _af_error (int errorCode)
+void _af_error (int errorCode, const char *fmt, ...)
 {
+	char	buf[1024];
+	va_list	ap;
+
+	va_start(ap, fmt);
+
+	vsnprintf(buf, 1024, fmt, ap);
+
+	va_end(ap);
+
 	if (errorFunction != NULL)
-		errorFunction(errorCode, errordescription(errorCode));
+		errorFunction(errorCode, buf);
 }
 
 static const char *errordescription (int error)
