@@ -21,6 +21,6 @@
 #ifndef ERROR_H
 #define ERROR_H
 
-void _af_error (int errorCode);
+void _af_error (int errorCode, const char *fmt, ...);
 
 #endif
