@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998-1999, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -30,6 +30,10 @@
 #include "afinternal.h"
 #include "audiofile.h"
 #include "aupvlist.h"
+#include "unit.h"
+#include "instrument.h"
+
+extern _Unit _af_units[];
 
 static struct _Instrument *initInstrument (struct _Instrument *instrument);
 static struct _Instrument *findInstrumentByID (int id,
@@ -151,7 +155,7 @@ void afSetInstParams (AFfilehandle file, int instid, AUpvlist pvlist,
 				break;
 
 			default:
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 				break;
 		}
 	}
@@ -188,7 +192,7 @@ void afGetInstParams (AFfilehandle file, int instid, AUpvlist pvlist,
 				break;
 
 			default:
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 				break;
 		}
 	}
@@ -207,7 +211,7 @@ void afSetInstParamLong (AFfilehandle file, int instid, int parameter,
 
 	if (instrument == NULL)
 	{
-		_af_error(AF_BAD_INSTID);
+		_af_error(AF_BAD_INSTID, "bad instrument parameter id");
 		return;
 	}
 
@@ -217,7 +221,7 @@ void afSetInstParamLong (AFfilehandle file, int instid, int parameter,
 			if (parameter >= 0 && parameter <= 127)
 				instrument->midiBaseNote = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 
 			break;
 
@@ -229,28 +233,28 @@ void afSetInstParamLong (AFfilehandle file, int instid, int parameter,
 			if (parameter >= 0 && parameter <= 127)
 				instrument->midiLowNote = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		case AF_INST_MIDI_HINOTE:
 			if (parameter >= 0 && parameter <= 127)
 				instrument->midiHighNote = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		case AF_INST_MIDI_LOVELOCITY:
 			if (parameter >= 1 && parameter <= 127)
 				instrument->midiLowVelocity = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		case AF_INST_MIDI_HIVELOCITY:
 			if (parameter >= 1 && parameter <= 127)
 				instrument->midiHighVelocity = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		case AF_INST_NUMDBS_GAIN:
@@ -261,18 +265,18 @@ void afSetInstParamLong (AFfilehandle file, int instid, int parameter,
 			if (parameter >= 1)
 				instrument->sustainLoopID = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		case AF_INST_RELLOOPID:
 			if (parameter >= 1)
 				instrument->releaseLoopID = parameter;
 			else
-				_af_error(AF_BAD_INSTPID);
+				_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 
 		default:
-			_af_error(AF_BAD_INSTPID);
+			_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 	}
 }
@@ -289,7 +293,7 @@ long afGetInstParamLong (AFfilehandle file, int instid, int parameter)
 
 	if (instrument == NULL)
 	{
-		/* _af_error(AF_BAD_INSTID); */
+		_af_error(AF_BAD_INSTID, "bad instrument id");
 		return 0;
 	}
 
@@ -323,9 +327,30 @@ long afGetInstParamLong (AFfilehandle file, int instid, int parameter)
 			return instrument->releaseLoopID;
 			break;
 		default:
-			/* _af_error(AF_BAD_INSTPID); */
+			_af_error(AF_BAD_INSTPID, "bad instrument parameter id");
 			break;
 	}
 
 	return 0;
 }
+
+/*
+	Search _af_units[fileFormat].instrumentParameters for the instrument
+	parameter with the specified id.
+*/
+int _af_instparam_index_from_instparam_id (int fileFormat, int id)
+{
+	int	i;
+
+	for (i=0; i<_af_units[fileFormat].instrumentParameterCount; i++)
+		if (_af_units[fileFormat].instrumentParameters[i].id == id)
+			break;
+
+	if (i == _af_units[fileFormat].instrumentParameterCount)
+	{
+		_af_error(AF_BAD_INSTPID, "invalid instrument parameter id %d", id);
+		return -1;
+	}
+
+	return i;
+}
