@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998, Michael Pruett <michael@68k.org>
+	Copyright (C) 2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -21,17 +21,16 @@
 /*
 	instrument.h
 
-	This file contains the interfaces to routines dealing with the
-	Audio File Library's internal instrument data types.
+	This file declares routines for dealing with instruments.
 */
 
 #ifndef INSTRUMENT_H
 #define INSTRUMENT_H
 
-#include "afinternal.h"
+/*
+	Search _af_units[fileFormat].instrumentParameters for the instrument
+	parameter with the specified id.
+*/
+int _af_instparam_index_from_instparam_id (int fileFormat, int id);
 
-struct _Instrument *initInstrument (struct _Instrument *instrument);
-struct _Instrument *findInstrumentByID (int id,
-	struct _Instrument *instruments, int count);
-
-#endif
+#endif /* INSTRUMENT_H */
