@@ -25,11 +25,12 @@
 	internal loop data structures.
 */
 
-#include <stdlib.h>
 #include <assert.h>
+#include <stdlib.h>
 
 #include "audiofile.h"
 #include "afinternal.h"
+#include "util.h"
 
 static struct _Loop *initLoop (struct _Loop *loop);
 static struct _Loop *findLoopByID (int id, struct _Loop *loops, int count);
@@ -78,7 +79,7 @@ void afInitLoopIDs (AFfilesetup setup, int instid, int *ids, int nids)
 	if (nids != setup->loopCount)
 	{
 		setup->loopCount = nids;
-		setup->loops = realloc(setup->loops,
+		setup->loops = _af_realloc(setup->loops,
 			setup->loopCount * sizeof (struct _Loop));
 	}
 
@@ -118,7 +119,7 @@ void afSetLoopMode (AFfilehandle file, int instid, int loopid, int mode)
 	loop = findLoopByID(loopid, file->loops, file->loopCount);
 	if (loop == NULL)
 	{
-		_af_error(AF_BAD_LOOPID);
+		_af_error(AF_BAD_LOOPID, "bad loop id");
 		return;
 	}
 
@@ -135,7 +136,7 @@ int afGetLoopMode (AFfilehandle file, int instid, int loopid)
 	loop = findLoopByID(loopid, file->loops, file->loopCount);
 	if (loop == NULL)
 	{
-		_af_error(AF_BAD_LOOPID);
+		_af_error(AF_BAD_LOOPID, "bad loop id");
 		return -1;
 	}
 
@@ -152,7 +153,7 @@ int afSetLoopCount (AFfilehandle file, int instid, int loopid, int count)
 	loop = findLoopByID(loopid, file->loops, file->loopCount);
 	if (loop == NULL)
 	{
-		_af_error(AF_BAD_LOOPID);
+		_af_error(AF_BAD_LOOPID, "bad loop id");
 		return -1;
 	}
 
@@ -314,7 +315,7 @@ void afSetLoopTrack (AFfilehandle file, int instid, int loopid, int trackid)
 	loop = findLoopByID(loopid, file->loops, file->loopCount);
 	if (loop == NULL)
 	{
-		_af_error(AF_BAD_LOOPID);
+		_af_error(AF_BAD_LOOPID, "bad loop id");
 	}
 }
 
@@ -329,7 +330,7 @@ int afGetLoopTrack (AFfilehandle file, int instid, int loopid)
 
 	if (loop == NULL)
 	{
-		_af_error(AF_BAD_LOOPID);
+		_af_error(AF_BAD_LOOPID, "bad loop id");
 		return -1;
 	}
 
