@@ -84,7 +84,7 @@ void afInitMarkName(AFfilesetup setup, int trackid, int markid,
 
 	if (marker == NULL)
 	{
-		_af_error(AF_BAD_MARKID);
+		_af_error(AF_BAD_MARKID, "bad marker id");
 		return;
 	}
 
@@ -117,7 +117,7 @@ char *afGetMarkName (AFfilehandle file, int trackid, int markid)
 
 	if (marker == NULL)
 	{
-		_af_error(AF_BAD_MARKID);
+		_af_error(AF_BAD_MARKID, "bad marker id");
 		return NULL;
 	}
 
@@ -146,7 +146,7 @@ void afSetMarkPosition (AFfilehandle file, int trackid, int markid,
 	marker = findMarkerByID(markid, file->markers, file->markerCount);
 	if (marker == NULL)
 	{
-		_af_error(AF_BAD_MARKID);
+		_af_error(AF_BAD_MARKID, "bad marker id");
 		return;
 	}
 
@@ -183,7 +183,7 @@ AFframecount afGetMarkPosition (AFfilehandle file, int trackid, int markid)
 
 	if (marker == NULL)
 	{
-		_af_error(AF_BAD_MARKID);
+		_af_error(AF_BAD_MARKID, "bad marker id");
 		return -1;
 	}
 
