@@ -110,7 +110,7 @@ void afInitMiscType (AFfilesetup setup, int miscellaneousid, int type)
 	if (miscellaneous)
 		miscellaneous->type = type;
 	else
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 }
 
 int afGetMiscType (AFfilehandle file, int miscellaneousid)
@@ -128,7 +128,7 @@ int afGetMiscType (AFfilehandle file, int miscellaneousid)
 	}
 	else
 	{
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 		return -1;
 	}
 }
@@ -147,7 +147,7 @@ void afInitMiscSize (AFfilesetup setup, int miscellaneousid, int size)
 		miscellaneous->size = size;
 	}
 	else
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 }
 
 int afGetMiscSize (AFfilehandle file, int miscellaneousid)
@@ -165,7 +165,7 @@ int afGetMiscSize (AFfilehandle file, int miscellaneousid)
 	}
 	else
 	{
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 		return -1;
 	}
 }
@@ -182,7 +182,7 @@ int afWriteMisc (AFfilehandle file, int miscellaneousid, void *buf, int bytes)
 
 	if (miscellaneous == NULL)
 	{
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 		return -1;
 	}
 	else
@@ -205,7 +205,7 @@ int afWriteMisc (AFfilehandle file, int miscellaneousid, void *buf, int bytes)
 		assert(bytes + miscellaneous->position <= miscellaneous->size);
 		if (bytes + miscellaneous->position > miscellaneous->size)
 		{
-			_af_error(AF_BAD_MISCSEEK);
+			_af_error(AF_BAD_MISCSEEK, "bad miscellaneous seek");
 			return -1;
 		}
 
@@ -228,7 +228,7 @@ int afReadMisc (AFfilehandle file, int miscellaneousid, void *buf, int bytes)
 
 	if (miscellaneous == NULL)
 	{
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 		return -1;
 	}
 	else
@@ -246,9 +246,9 @@ int afReadMisc (AFfilehandle file, int miscellaneousid, void *buf, int bytes)
 			I'd be surprised if anyone ever used this function.
 		*/
 		if (miscellaneous->size == 0)
-			_af_error(AF_BAD_MISCSIZE);
+			_af_error(AF_BAD_MISCSIZE, "bad miscellaneous size");
 		if (miscellaneous->position + bytes > miscellaneous->size)
-			_af_error(AF_BAD_MISCSEEK);
+			_af_error(AF_BAD_MISCSEEK, "bad miscellaneous seek");
 
 		af_fseek(file->fh, miscellaneous->offset + miscellaneous->position, SEEK_SET);
 		result = af_fread(buf, bytes, 1, file->fh);
@@ -269,14 +269,14 @@ int afSeekMisc (AFfilehandle file, int miscellaneousid, int offset)
 
 	if (miscellaneous == NULL)
 	{
-		_af_error(AF_BAD_MISCID);
+		_af_error(AF_BAD_MISCID, "bad miscellaneous id");
 		return 0;
 	}
 
 	assert(offset <= miscellaneous->size);
 
 	if (offset < 0 || offset > miscellaneous->size)
-		_af_error(AF_BAD_MISCSEEK);
+		_af_error(AF_BAD_MISCSEEK, "bad miscellaneous seek");
 
 	miscellaneous->position = offset;
 
