@@ -88,7 +88,7 @@ static AFframecount _af_g711_ulawReadFrames (AFfilehandle file, int track,
 	if (af_fseek(file->fh, file->dataStart + file->currentFrame * frameSize,
 		SEEK_SET) != 0)
 	{
-		_af_error(AF_BAD_LSEEK);
+		_af_error(AF_BAD_LSEEK, "bad seek");
 		return 0;
 	}
 
@@ -100,7 +100,7 @@ static AFframecount _af_g711_ulawReadFrames (AFfilehandle file, int track,
 		{
 			if (af_fread(&datum, 1, 1, file->fh) < 1)
 			{
-				_af_error(AF_BAD_READ);
+				_af_error(AF_BAD_READ, "bad read");
 				break;
 			}
 			*buffer16 = _af_ulaw2linear(datum);
@@ -144,7 +144,7 @@ static AFframecount _af_g711_ulawWriteFrames (AFfilehandle file, int track,
 	if (af_fseek(file->fh, file->dataStart + file->currentFrame * frameSize/2,
 		SEEK_SET) != 0)
 	{
-		_af_error(AF_BAD_LSEEK);
+		_af_error(AF_BAD_LSEEK, "bad seek");
 		return 0;
 	}
 
@@ -170,7 +170,7 @@ static AFframecount _af_g711_ulawWriteFrames (AFfilehandle file, int track,
 
 			if (af_fwrite(&ulawdatum, 1, 1, file->fh) < 1)
 			{
-				_af_error(AF_BAD_WRITE);
+				_af_error(AF_BAD_WRITE, "bad write");
 				break;
 			}
 			done++;
