@@ -1,6 +1,6 @@
 /*
 	Audio File Library
-	Copyright (C) 1998, Michael Pruett <michael@68k.org>
+	Copyright (C) 1998-2000, Michael Pruett <michael@68k.org>
 
 	This library is free software; you can redistribute it and/or
 	modify it under the terms of the GNU Library General Public
@@ -33,5 +33,12 @@
 
 void _af_printid (u_int32_t id);
 void _af_printfilehandle (AFfilehandle filehandle);
+void *_af_malloc (size_t size);
+void *_af_realloc (void *ptr, size_t size);
+void *_af_calloc (size_t nmemb, size_t size);
+
+AUpvlist _af_pv_long (long val);
+AUpvlist _af_pv_double (double val);
+AUpvlist _af_pv_pointer (void *val);
 
 #endif
