@@ -43,14 +43,25 @@
 extern struct _Compression g711_ulaw_compression;
 extern struct _Compression g711_alaw_compression;
 
-static void ParseFormat (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t id,
-	size_t size);
-static void ParseData (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t id,
-	size_t size);
-int _af_parsewave (AFfilehandle file);
+int _af_wave_compression_types[_AF_WAVE_NUM_COMPTYPES] =
+{
+	AF_COMPRESSION_G711_ULAW,
+	AF_COMPRESSION_G711_ALAW
+};
 
-static void ParseFormat (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t id,
-	size_t size)
+_InstParamInfo _af_wave_inst_params[_AF_WAVE_NUM_INSTPARAMS] =
+{
+	{ AF_INST_MIDI_BASENOTE, AU_PVTYPE_LONG, "MIDI base note", {60} },
+	{ AF_INST_NUMCENTS_DETUNE, AU_PVTYPE_LONG, "Detune in cents", {0} },
+	{ AF_INST_MIDI_LOVELOCITY, AU_PVTYPE_LONG, "Low velocity", {1} },
+	{ AF_INST_MIDI_HIVELOCITY, AU_PVTYPE_LONG, "High velocity", {127} },
+	{ AF_INST_MIDI_LONOTE, AU_PVTYPE_LONG, "Low note", {0} },
+	{ AF_INST_MIDI_HINOTE, AU_PVTYPE_LONG, "High note", {127} },
+	{ AF_INST_NUMDBS_GAIN, AU_PVTYPE_LONG, "Gain in dB", {0} }
+};
+
+static status ParseFormat (AFfilehandle filehandle, AF_VirtualFile *fp,
+	u_int32_t id, size_t size)
 {
 	u_int16_t	formatTag, channelCount;
 	u_int32_t	sampleRate, averageBytesPerSecond;
@@ -88,7 +99,13 @@ static void ParseFormat (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t
 
 			filehandle->sampleWidth = bitsPerSample;
 
-			assert(bitsPerSample > 0 && bitsPerSample <= 32);
+			if (bitsPerSample < 0 && bitsPerSample >= 32)
+			{
+				_af_error(AF_BAD_WIDTH,
+					"bad sample width of %d bits",
+					bitsPerSample);
+				return AF_FAIL;
+			}
 
 #if 0
 			if (bitsPerSample <= 8)
@@ -108,46 +125,64 @@ static void ParseFormat (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t
 			filehandle->sampleWidth = 16;
 			filehandle->compression = &g711_alaw_compression;
 			break;
+
+		default:
+			_af_error(AF_BAD_FILEFMT, "bad file format");
+			return AF_FAIL;
+			break;
 	}
+
+	return AF_SUCCEED;
 }
 
-static void ParseData (AFfilehandle filehandle, AF_VirtualFile *fp, u_int32_t id,
-	size_t size)
+static status ParseData (AFfilehandle filehandle, AF_VirtualFile *fp,
+	u_int32_t id, size_t size)
 {
-	u_int32_t	frameSize;
-
 	assert(filehandle != NULL);
 	assert(fp != NULL);
 	assert(!memcmp(&id, "data", 4));
 
-	/* We always round up to the nearest byte for the frame size. */
-	frameSize = filehandle->channelCount * ((filehandle->sampleWidth + 7) / 8);
-
 	filehandle->dataStart = af_ftell(fp);
 	filehandle->trackBytes = size;
-	filehandle->frameCount = size / frameSize;
 
-	if (filehandle->compression != NULL &&
-		(filehandle->compression->type == AF_COMPRESSION_G711_ULAW ||
-		filehandle->compression->type == AF_COMPRESSION_G711_ALAW))
-	{
-		filehandle->frameCount = size / filehandle->channelCount;
-	}
+	return AF_SUCCEED;
 }
 
-int _af_parsewave (AFfilehandle file)
+bool _af_wave_recognize (AFvirtualfile *fh)
+{
+	u_int8_t        buffer[8];
+
+	af_fseek(fh, 0, SEEK_SET);
+
+	if (af_fread(buffer, 1, 8, fh) != 8 || memcmp(buffer, "RIFF", 4) != 0)
+		return AF_FALSE;
+	if (af_fread(buffer, 1, 4, fh) != 4 || memcmp(buffer, "WAVE", 4) != 0)
+		return AF_FALSE;
+
+	return AF_TRUE;
+}
+
+status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 {
 	u_int32_t	type, size, formtype;
 	u_int32_t	index = 0;
-	int			hasFormat = 0, hasData = 0;
+	bool		hasFormat, hasData, hasCueList, hasFact;
+	int		frameSize;
 
-	assert(file != NULL);
-	assert(file->fh != NULL);
+	assert(filehandle != NULL);
+	assert(filehandle->fh != NULL);
 
-	af_fread(&type, 4, 1, file->fh);
-	af_fread(&size, 4, 1, file->fh);
+	hasFormat = AF_FALSE;
+	hasData = AF_FALSE;
+	hasCueList = AF_FALSE;
+	hasFact = AF_FALSE;
+
+	af_fseek(filehandle->fh, 0, SEEK_SET);
+
+	af_fread(&type, 4, 1, filehandle->fh);
+	af_fread(&size, 4, 1, filehandle->fh);
 	size = LENDIAN_TO_HOST_INT32(size);
-	af_fread(&formtype, 4, 1, file->fh);
+	af_fread(&formtype, 4, 1, filehandle->fh);
 
 	assert(!memcmp(&type, "RIFF", 4));
 	assert(!memcmp(&formtype, "WAVE", 4));
@@ -156,19 +191,21 @@ int _af_parsewave (AFfilehandle file)
 	printf("size: %d\n", size);
 #endif
 
+	filehandle->byteOrder = AF_BYTEORDER_LITTLEENDIAN;
+
+	/* Include the offset of the form type. */
 	index += 4;
 
-	/* include the offset of the form type */
 	while (index < size)
 	{
-		u_int32_t	chunkid, chunksize;
+		u_int32_t	chunkid = 0, chunksize = 0;
 
 #ifdef DEBUG
 		printf("index: %d\n", index);
 #endif
-		af_fread(&chunkid, 4, 1, file->fh);
+		af_fread(&chunkid, 4, 1, filehandle->fh);
 
-		af_fread(&chunksize, 4, 1, file->fh);
+		af_fread(&chunksize, 4, 1, filehandle->fh);
 		chunksize = LENDIAN_TO_HOST_INT32(chunksize);
 
 #ifdef DEBUG
@@ -178,27 +215,105 @@ int _af_parsewave (AFfilehandle file)
 
 		if (memcmp(&chunkid, "data", 4) == 0)
 		{
-			ParseData(file, file->fh, chunkid, chunksize);
-			hasData = 1;
+			status	result;
+
+			result = ParseData(filehandle, filehandle->fh, chunkid, chunksize);
+			if (result == AF_FAIL)
+				return AF_FAIL;
+
+			hasData = AF_TRUE;
 		}
 		else if (memcmp(&chunkid, "fmt ", 4) == 0)
 		{
-			ParseFormat(file, file->fh, chunkid, chunksize);
-			hasFormat = 1;
+			status	result;
+			result = ParseFormat(filehandle, filehandle->fh, chunkid, chunksize);
+			if (result == AF_FAIL)
+				return AF_FAIL;
+
+			hasFormat = AF_TRUE;
 		}
 
 		index += chunksize + 8;
 
-		/* all chunks must be aligned on an even number of bytes */
+		/* All chunks must be aligned on an even number of bytes */
 		if ((index % 2) != 0)
 			index++;
 
-		af_fseek(file->fh, index + 8, SEEK_SET);
+		af_fseek(filehandle->fh, index + 8, SEEK_SET);
 	}
 
-	/* The data chunk and the format chunk are required. */
-	assert(hasFormat && hasData);
+	/* The format chunk and the data chunk are required. */
+	if (!hasFormat || !hasData)
+		return AF_FAIL;
 
-	/* A return value of zero indicates successful parsing. */
-	return 0;
+	/*
+		At this point we know that the file has a format chunk and
+		a data chunk, so we can assume that channelCount,
+		sampleWidth, and trackBytes have been initialized.
+	*/
+
+	/*
+		We always round up to the nearest byte for the frame size.
+	*/
+	frameSize = filehandle->channelCount * ((filehandle->sampleWidth + 7) / 8);
+	filehandle->frameCount = filehandle->trackBytes / frameSize;
+
+	if (filehandle->compression != NULL &&
+		(filehandle->compression->type == AF_COMPRESSION_G711_ULAW ||
+		filehandle->compression->type == AF_COMPRESSION_G711_ALAW))
+	{
+		filehandle->frameCount = size / filehandle->channelCount;
+	}
+
+	/*
+		A return value of AF_SUCCEED indicates successful parsing.
+	*/
+	return AF_SUCCEED;
+}
+
+AFfilesetup _af_wave_complete_setup (AFfilesetup setup)
+{
+	return AF_NULL_FILESETUP;
+}
+
+bool _af_wave_instparam_valid (AFfilehandle filehandle, AUpvlist list, int i)
+{
+	int	param, type, lval;
+
+	AUpvgetparam(list, i, &param);
+	AUpvgetvaltype(list, i, &type);
+	if (type != AU_PVTYPE_LONG)
+		return AF_FALSE;
+
+	AUpvgetval(list, i, &lval);
+
+	switch (param)
+	{
+		case AF_INST_MIDI_BASENOTE:
+			return ((lval >= 0) && (lval <= 127));
+
+		case AF_INST_NUMCENTS_DETUNE:
+			return ((lval >= -50) && (lval <= 50));
+
+		case AF_INST_MIDI_LOVELOCITY:
+			return ((lval >= 1) && (lval <= 127));
+
+		case AF_INST_MIDI_HIVELOCITY:
+			return ((lval >= 1) && (lval <= 127));
+
+		case AF_INST_MIDI_LONOTE:
+			return ((lval >= 0) && (lval <= 127));
+
+		case AF_INST_MIDI_HINOTE:
+			return ((lval >= 0) && (lval <= 127));
+
+		case AF_INST_NUMDBS_GAIN:
+			return AF_TRUE;
+
+		default:
+			return AF_FALSE;
+			break;
+	}
+
+	return AF_TRUE;
 }
