@@ -43,13 +43,13 @@
 
 int waveWriteFrames (const AFfilehandle file, int track, void *samples,
 	const int count);
-int waveSyncFile (AFfilehandle file);
+status _af_wave_update (AFfilehandle file);
 
-static void WriteFormat (const AFfilehandle file);
+static status WriteFormat (const AFfilehandle file);
 static int WriteData (const AFfilehandle file, int track, void *samples,
 	const int count);
 
-static void WriteFormat (const AFfilehandle file)
+static status WriteFormat (const AFfilehandle file)
 {
 	u_int16_t	formatTag, channelCount;
 	u_int32_t	sampleRate, averageBytesPerSecond;
@@ -69,10 +69,15 @@ static void WriteFormat (const AFfilehandle file)
 			formatTag = WAVE_FORMAT_MULAW;
 		else if (file->compression->type == AF_COMPRESSION_G711_ALAW)
 			formatTag = WAVE_FORMAT_ALAW;
-		/*
-			We should raise an error about an unsupported
-			compression type.
-		*/
+		else
+		{
+			/*
+				Raise an error for this unsupported
+				compression type.
+			*/
+			_af_error(AF_BAD_COMPTYPE, "bad compression type");
+			return AF_FAIL;
+		}
 	}
 	else
 		formatTag = WAVE_FORMAT_PCM;
@@ -114,6 +119,8 @@ static void WriteFormat (const AFfilehandle file)
 		bitsPerSample = HOST_TO_LENDIAN_INT16(bitsPerSample);
 		af_fwrite(&bitsPerSample, 2, 1, file->fh);
 	}
+
+	return AF_SUCCEED;
 }
 
 /* Again, only 8-, 16-, or 32-bit sample widths are supported. */
@@ -181,7 +188,7 @@ int waveWriteFrames (const AFfilehandle file, int track, void *samples,
 	return result;
 }
 
-int waveSyncFile (AFfilehandle file)
+status _af_wave_update (AFfilehandle file)
 {
 	if (file->dataStart != 0)
 	{
@@ -204,8 +211,7 @@ int waveSyncFile (AFfilehandle file)
 		af_fseek(file->fh, file->dataStart - 4, SEEK_SET);
 		af_fwrite(&dataLength, 4, 1, file->fh);
 
-		af_fseek(file->fh, 0, SEEK_END);
-		fileLength = af_ftell(file->fh);
+		fileLength = af_flength(file->fh);
 		fileLength -= 8;
 		fileLength = HOST_TO_LENDIAN_INT32(fileLength);
 
@@ -213,5 +219,10 @@ int waveSyncFile (AFfilehandle file)
 		af_fwrite(&fileLength, 4, 1, file->fh);
 	}
 
-	return 0;
+	return AF_SUCCEED;
+}
+
+status _af_wave_write_init (AFfilesetup setup, AFfilehandle filehandle)
+{
+	return AF_FAIL;
 }
